@@ -13,14 +13,14 @@ A container for functions for the ack program.
 
 =head1 VERSION
 
-Version 2.999_03
+Version 2.999_04
 
 =cut
 
 our $VERSION;
 our $COPYRIGHT;
 BEGIN {
-    $VERSION = '2.999_03';
+    $VERSION = '2.999_04';
     $COPYRIGHT = 'Copyright 2005-2018 Andy Lester.';
 }
 our $STANDALONE = 0;
@@ -45,6 +45,9 @@ our $is_windows;
 
 our $debug_nopens = 0;
 
+# Line ending, changes to "\0" if --print0.
+our $ors = "\n";
+
 BEGIN {
     # These have to be checked before any filehandle diddling.
     $output_to_pipe  = not -t *STDOUT;
@@ -287,9 +290,10 @@ File presentation:
   --nogroup                     Same as --noheading --nobreak
   --[no]proximate               Separate match output with blank lines unless
                                 they are on adjacent lines.
-  --[no]color                   Highlight the matching text (default: on unless
+  -P                            Negates --proximate.
+  --[no]underline               Print a line of carets under the matched text.
+  --[no]color, --[no]colour     Highlight the matching text (default: on unless
                                 output is redirected, or on Windows)
-  --[no]colour                  Same as --[no]color
   --color-filename=COLOR
   --color-match=COLOR
   --color-colno=COLOR
@@ -472,8 +476,9 @@ END_OF_VERSION
 }
 
 
-sub print                   { print {$fh} @_; return; }
-sub print_blank_line        { App::Ack::print( "\n" ); return; }
+sub print            { print {$fh} @_; return; }
+sub say              { print {$fh} @_, $ors; return; }
+sub print_blank_line { print {$fh} "\n"; return; }
 
 sub set_up_pager {
     my $command = shift;
@@ -515,7 +520,7 @@ sub exit_from_ack {
     exit $rc;
 }
 
-=head2 show_types( $file, $ors )
+=head2 show_types( $file )
 
 Shows the filetypes associated with a given file.
 
@@ -523,12 +528,10 @@ Shows the filetypes associated with a given file.
 
 sub show_types {
     my $file = shift;
-    my $ors  = shift;
 
     my @types = filetypes( $file );
-    my $types = join( ',', @types );
     my $arrow = @types ? ' => ' : ' =>';
-    App::Ack::print( $file->name, $arrow, join( ',', @types ), $ors );
+    App::Ack::say( $file->name, $arrow, join( ',', @types ) );
 
     return;
 }
