@@ -11,7 +11,6 @@ use App::Ack::Filter ();
 use App::Ack::Filter::Collection ();
 use App::Ack::Filter::Default ();
 use App::Ack::Filter::IsPath ();
-use Carp 1.04 ();
 use File::Spec 3.00 ();
 use Getopt::Long 2.38 ();
 use Text::ParseWords 3.1 ();
@@ -26,29 +25,25 @@ Logic for loading configuration files.
 
 =head1 FUNCTIONS
 
-=head2 process_args( @sources )
-
 =cut
 
-my @INVALID_COMBINATIONS;
-
-BEGIN {
+sub _invalid_combinations {
     my @context    = qw( -A -B -C --after-context --before-context --context );
     my @pretty     = qw( --heading --group --break );
     my @filename   = qw( -h -H --with-filename --no-filename );
     my @file_lists = qw( -f -g -l -L );
 
-    @INVALID_COMBINATIONS = (
+    return (
         [qw(-l)]                 => [@context, @pretty, @filename, qw(-L -o --passthru --output --max-count --column -f -g --show-types)],
-        [qw(-L)]                 => [@context, @pretty, @filename, qw(-l -o --passthru --output --max-count --column -f -g --show-types -c --count)],
+        [qw(-L)]                 => [@context, @pretty, @filename, qw(-l -o --passthru --output --max-count --column -f -g --show-types -c --count -v)],
         [qw(--lines)]            => [@context, @pretty, @filename, qw(-l --files-with-matches --files-without-matches -L -o --passthru --match -m --max-count -1 -c --count --column --print0 -f -g --show-types)],
         [qw(-o)]                 => [@context, qw(--output -c --count --column --column -f --show-types)],
-        [qw(--passthru)]         => [@context, qw(--output --column -m --max-count -1 -c --count -f -g)],
-        [qw(--output)]           => [@context, qw(-c --count -f -g)],
+        [qw(--passthru)]         => [@context, @file_lists, qw(--output --column -m --max-count -1 -c --count -f -g)],
+        [qw(--output)]           => [@context, @file_lists, qw(-c --count)],
         [qw(--match)]            => [qw(-f -g)],
         [qw(-m --max-count)]     => [qw(-1 -f -g -c --count)],
-        [qw(-h --no-filename)]   => [qw(-H --with-filename -f -g --group --heading)],
-        [qw(-H --with-filename)] => [qw(-h --no-filename -f -g)],
+        [qw(-h --no-filename)]   => [@file_lists, qw(-H --with-filename --group --heading)],
+        [qw(-H --with-filename)] => [@file_lists, qw(-h --no-filename)],
         [qw(-c --count)]         => [@context, @pretty, qw(--column -f -g)],
         [qw(--column)]           => [@file_lists],
         [@context]               => [@file_lists],
@@ -74,7 +69,7 @@ sub _generate_ignore_dir {
         my ( $filter_type, $args ) = split /:/, $dir, 2;
 
         if ( $filter_type eq 'firstlinematch' ) {
-            Carp::croak( qq{Invalid filter specification "$filter_type" for option '$option_name'} );
+            App::Ack::die( qq{Invalid filter specification "$filter_type" for option '$option_name'} );
         }
 
         my $filter = App::Ack::Filter->create_filter($filter_type, split(/,/, $args));
@@ -141,7 +136,7 @@ sub _process_filter_spec {
         return ( $type_name, App::Ack::Filter->create_filter('ext', @extensions) );
     }
     else {
-        Carp::croak "invalid filter specification '$spec'";
+        App::Ack::die( "Invalid filter specification '$spec'" );
     }
 }
 
@@ -234,7 +229,7 @@ sub _process_filetypes {
     );
 
     foreach my $source (@{$arg_sources}) {
-        my ( $source_name, $args ) = @{$source}{qw/name contents/};
+        my $args = $source->{contents};
 
         if ( ref($args) ) {
             # $args are modified in place, so no need to munge $arg_sources
@@ -249,8 +244,6 @@ sub _process_filetypes {
     }
 
     $additional_specs{'k|known-types'} = sub {
-        my ( undef, $value ) = @_;
-
         my @filters = map { @{$_} } values(%App::Ack::mappings);
 
         push @{ $opt->{'filters'} }, @filters;
@@ -353,6 +346,7 @@ sub get_arg_spec {
         'passthru'          => \$opt->{passthru},
         'print0'            => \$opt->{print0},
         'proximate:1'       => \$opt->{proximate},
+        'P'                 => sub { $opt->{proximate} = 0 },
         'Q|literal'         => \$opt->{Q},
         'r|R|recurse'       => sub { $opt->{n} = 0 },
         's'                 => \$opt->{s},
@@ -373,7 +367,7 @@ sub get_arg_spec {
                 $callback->( $getopt, $cb_value );
             }
             else {
-                Carp::croak( "Unknown type '$value'" );
+                App::Ack::die( "Unknown type '$value'" );
             }
         },
         'u|underline!'      => \$opt->{u},
@@ -637,7 +631,7 @@ sub _remove_default_options_if_needed {
     );
 
     foreach my $index ( $default_index + 1 .. $#{$sources} ) {
-        my ( $name, $args ) = @{$sources->[$index]}{qw/name contents/};
+        my $args = $sources->[$index]->{contents};
 
         if (ref($args)) {
             local @ARGV = @{$args};
@@ -670,8 +664,9 @@ sub _check_for_mutually_exclusive_options {
     my %mutually_exclusive_with;
     my @copy = @{$arg_sources};
 
-    for ( my $i = 0; $i < @INVALID_COMBINATIONS; $i += 2 ) {
-        my ( $lhs, $rhs ) = @INVALID_COMBINATIONS[ $i, $i + 1 ];
+    my @combos = _invalid_combinations();
+    for ( my $i = 0; $i < @combos; $i += 2 ) {
+        my ( $lhs, $rhs ) = @combos[ $i, $i + 1 ];
 
         foreach my $l_opt ( @{$lhs} ) {
             foreach my $r_opt ( @{$rhs} ) {
@@ -685,7 +680,7 @@ sub _check_for_mutually_exclusive_options {
         my %set_opts;
 
         my $source = shift @copy;
-        my ( $source_name, $args ) = @{$source}{qw/name contents/};
+        my $args = $source->{contents};
         $args = ref($args) ? [ @{$args} ] : [ Text::ParseWords::shellwords($args) ];
 
         foreach my $opt ( @{$args} ) {
@@ -717,6 +712,10 @@ sub _check_for_mutually_exclusive_options {
 }
 
 
+=head2 process_args( @sources )
+
+=cut
+
 sub process_args {
     my $arg_sources = \@_;
 
@@ -745,11 +744,11 @@ sub process_args {
                 @ARGV = @{$args};
             }
             elsif (@{$args}) {
-                Carp::croak "source '$source_name' has extra arguments!";
+                App::Ack::die( "Source '$source_name' has extra arguments!" );
             }
         }
         else {
-            Carp::croak 'The impossible has occurred!';
+            App::Ack::die( 'The impossible has occurred!' );
         }
     }
     my $filters = ($opt{filters} ||= []);
